@@ -4,8 +4,8 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      $Id: helpers.h 2945 2010-08-01 14:03:12Z mbarbon $
-// Copyright:   (c) 2000-2010 Mattia Barbon
+// RCS-ID:      $Id: helpers.h 2526 2009-02-07 14:35:21Z mbarbon $
+// Copyright:   (c) 2000-2009 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
@@ -333,8 +333,8 @@ wxGBSpan wxPli_sv_2_wxgbspan( pTHX_ SV* scalar );
 #if WXPERL_W_VERSION_GE( 2, 9, 0 )
 class wxPosition;
 wxPosition wxPli_sv_2_wxposition( pTHX_ SV* scalar );
+wxVariant wxPli_sv_2_wxvariant( pTHX_ SV* scalar );
 #endif
-wxVariant FUNCPTR( wxPli_sv_2_wxvariant )( pTHX_ SV* scalar );
 
 wxKeyCode wxPli_sv_2_keycode( pTHX_ SV* scalar );
 
@@ -416,14 +416,16 @@ SV* FUNCPTR( wxPliVirtualCallback_CallCallback )
     ( pTHX_ const wxPliVirtualCallback* cb, I32 flags,
       const char* argtypes, ... );
 
-// used in overload.cpp
+// defined in overload.cpp
 struct wxPliPrototype
 {
-    wxPliPrototype( const char** const proto,
-                    const size_t proto_size )
-      : args( proto ), count( proto_size ) { }
+    wxPliPrototype( const char** const t,
+                    const unsigned char* const a,
+                    const size_t c )
+      : tnames( t ), args( a ), count( c ) { }
 
-    const char** const args;
+    const char** const tnames;
+    const unsigned char* const args;
     const size_t count;
 };
 
@@ -433,8 +435,6 @@ bool wxPli_match_arguments( pTHX_ const wxPliPrototype& prototype,
 bool FUNCPTR( wxPli_match_arguments_skipfirst )( pTHX_ const wxPliPrototype& p,
                                                  int required,
                                                  bool allow_more );
-void FUNCPTR( wxPli_overload_error )( pTHX_ const char* function,
-                                      wxPliPrototype* prototypes[] );
 
 #define WXPLI_BOOT_ONCE_( name, xs ) \
 bool name##_booted = false; \
@@ -525,9 +525,6 @@ struct wxPliHelpers
     void (* m_wxPli_objlist_push )( pTHX_ const wxList& objs );
     wxPliOutputStream* ( * m_wxPliOutputStream_ctor )( SV* );
     void (* m_wxPli_stringarray_push )( pTHX_ const wxArrayString& );
-    void (* m_wxPli_overload_error )( pTHX_ const char* function,
-                                      wxPliPrototype* prototypes[] );
-    wxVariant (* m_wxPli_sv_2_wxvariant )( pTHX_ SV* scalar );
 };
 
 #if wxPERL_USE_THREADS
@@ -570,8 +567,7 @@ wxPliHelpers name = { &wxPli_sv_2_object, \
  wxDEFINE_PLI_HELPER_THREADS() \
  wxDEFINE_PLI_HELPER_UNICODE() \
  &wxPli_av_2_arrayint, &wxPli_set_events, &wxPli_av_2_arraystring, \
- &wxPli_objlist_push, &wxPliOutputStream_ctor, &wxPli_stringarray_push, \
- &wxPli_overload_error, &wxPli_sv_2_wxvariant \
+ &wxPli_objlist_push, &wxPliOutputStream_ctor, &wxPli_stringarray_push \
  }
 
 #if NEEDS_PLI_HELPERS_STRUCT()
@@ -616,8 +612,6 @@ wxPliHelpers name = { &wxPli_sv_2_object, \
   wxPli_objlist_push = name->m_wxPli_objlist_push; \
   wxPliOutputStream_ctor = name->m_wxPliOutputStream_ctor; \
   wxPli_av_2_stringarray = name->m_wxPli_av_2_stringarray; \
-  wxPli_overload_error = name->m_wxPli_overload_error; \
-  wxPli_sv_2_wxvariant = name->m_wxPli_sv_2_wxvariant; \
   WXPLI_INIT_CLASSINFO();
 
 #else
